==> pochy-0.2-src.tar.gz: pochy-0.2-src/HeaderInfo.h <==
// HeaderInfo.h: CHeaderInfo NX̃C^[tFCX
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_MAILHEADER_H__FAC79C45_0FED_4C24_BDE2_CACDCD3C7F72__INCLUDED_)
#define AFX_MAILHEADER_H__FAC79C45_0FED_4C24_BDE2_CACDCD3C7F72__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define SEVEN_BIT (0)
#define EIGHT_BIT (1)
#define BIN (3)
#define BASE64 (4)
#define QUOTED_PRINTABLE (5)

class CHeaderInfo
{
public:
	CString GetCSubType();
	CString GetCType();
	CString GetTo();
	CString GetCc();
	CString GetBcc();
	CString GetDate();
	CString GetFrom();
	CString GetXmailer();
	CString GetSubject();
	CString GetReplyTo();
	CString GetMsgID();
	CString GetInReplyTo();
	CString GetCT();
	CString GetCD();
	int GetEnc();
	CString GetCTE();
	CString GetBoundary();
	CString GetCharset();
	CString GetFilename();
	CString GetName();
	CString GetProtocol();
	CString GetXattachment();
	BOOL IsMultipart();
	CString ReformDate(CString buf);
	void Decode();
	void RemoveFoldingWhiteSpace(CStringArray *header);
	void RemoveLinearWhiteSpace(CStringArray *header);
	CString GetOneLine(LPCTSTR key);
	CString GetAllDecoded();
	CString GetAllUnDecoded();
	void GetAllUnDecoded(CStringArray &header);
	void Analyze();
	void AnalyzeCT();
	void AnalyzeCD();
	BOOL DoIt(CStringArray &buf);
	CHeaderInfo(CString buf);
	CHeaderInfo();
	virtual ~CHeaderInfo();

protected:
	CString m_subtype;
	CString m_type;
	CString m_date;
	CString m_xmailer;
	CString m_cc;
	CString m_bcc;
	CString m_from;
	CString m_to;
	CString m_subject;
	CString m_replyto;
	CString m_msg_id;
	CString m_in_reply_to;
	CString m_ct;
	CString m_cd;
	CString m_cte;
	CString m_boundary;
	CString m_charset;
	CString m_name;
	CString m_filename;
	CString m_protocol;
	CString m_xattachment;
	CStringArray m_decoded_header;
	CStringArray m_undecoded_header;
	int m_enc;
private:
	void InitMemVal();
};

#endif // !defined(AFX_MAILHEADER_H__FAC79C45_0FED_4C24_BDE2_CACDCD3C7F72__INCLUDED_)

==> pochy-0.2.1-src.tar.gz: pochy-0.2.1-src/HeaderInfo.h <==
// HeaderInfo.h: CHeaderInfo NX̃C^[tFCX
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_MAILHEADER_H__FAC79C45_0FED_4C24_BDE2_CACDCD3C7F72__INCLUDED_)
#define AFX_MAILHEADER_H__FAC79C45_0FED_4C24_BDE2_CACDCD3C7F72__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define SEVEN_BIT (0)
#define EIGHT_BIT (1)
#define BIN (3)
#define BASE64 (4)
#define QUOTED_PRINTABLE (5)

class CHeaderInfo
{
public:
	CString GetHeaderFieldBody(CString field_name);
	CString GetCSubType();
	CString GetCType();
	CString GetTo();
	CString GetCc();
	CString GetBcc();
//	CString GetLocalDate();
	CString GetDate();
	CString GetFrom();
	CString GetXmailer();
	CString GetSubject();
	CString GetReplyTo();
	CString GetMsgID();
	CString GetInReplyTo();
	CString GetCT();
	CString GetCD();
	int GetEnc();
	CString GetCTE();
	CString GetBoundary();
	CString GetCharset();
	CString GetFilename();
	CString GetName();
	CString GetProtocol();
	CString GetPopfileLink();
	BOOL IsMultipart();
//	CString ReformDate(CString buf);
	void Decode();
	void RemoveFoldingWhiteSpace(CStringArray *header);
	void RemoveLinearWhiteSpace(CStringArray *header);
	CString GetOneLine(LPCTSTR key);
	CString GetAllDecoded();
	CString GetAllUnDecoded();
	void GetAllUnDecoded(CStringArray &header);
	void Analyze();
	void AnalyzeCT();
	void AnalyzeCD();
	BOOL DoIt(CStringArray &buf);
	CHeaderInfo(CString buf);
	CHeaderInfo();
	virtual ~CHeaderInfo();

protected:
	CString m_subtype;
	CString m_type;
	CString m_date;
//	CString m_local_date;
	CString m_xmailer;
	CString m_cc;
	CString m_bcc;
	CString m_from;
	CString m_to;
	CString m_subject;
	CString m_replyto;
	CString m_msg_id;
	CString m_in_reply_to;
	CString m_ct;
	CString m_cd;
	CString m_cte;
	CString m_boundary;
	CString m_charset;
	CString m_name;
	CString m_filename;
	CString m_protocol;
	CString m_popfile_link;
	CStringArray m_decoded_header;
	CStringArray m_undecoded_header;
	int m_enc;
private:
	void InitMemVal();
};

#endif // !defined(AFX_MAILHEADER_H__FAC79C45_0FED_4C24_BDE2_CACDCD3C7F72__INCLUDED_)
